# NCBI

This module allows for direct access to APIs provided by NCBI.
Currently the following submodules are provided:

| Submodule | Description |
|-----------|-------------|
| [`taxons`](./ncbi/taxons.md) | Retrieves taxon information from NCBI from a query string | 
| [`query-ids`](./ncbi/query_ids.md) | Retrieves information for a list of IDs | 
| [`query-symbols`](./ncbi/query_symbols.md) | Retrieves information for a list of symbols (must provide taxon) | 

